@@ -54,6 +54,10 @@ class NetcatsTool(Tool):
         #    dict(dest='open')),
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     def __init__(self, options, outfile=sys.stdout, *args, **kw):
         super(NetcatsTool, self).__init__(options, *args, **kw)
         self._outfile = outfile
@@ -184,9 +188,9 @@ class NetcatsTool(Tool):
 
 
 def main():
-    import xnet.tools
+    import xnet.tools.run
     #xnet.tools.run(NetcatsTool, stdin_data_arg='stdin_data')
-    xnet.tools.run(NetcatsTool, tool_reads_stdin=True)
+    xnet.tools.run.run(NetcatsTool, tool_reads_stdin=True)
 
 
 if __name__ == "__main__":
