@@ -39,6 +39,10 @@ class SSLInfoTool(Tool):
             dict(dest='cn', action='store_true'))
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     @classmethod
     def __massage__(self, iterator):
         for item in iterator:
@@ -166,8 +170,8 @@ Format variables available for %s.
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(SSLInfoTool)
+    import xnet.tools.run
+    xnet.tools.run.run(SSLInfoTool)
 
 
 if __name__ == "__main__":
