@@ -38,6 +38,10 @@ class WebgetTool(Tool):
             dict(dest='code', action='store_true')),
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     def __init__(self, *args, **kw):
         super(WebgetTool, self).__init__(*args, **kw)
         self._url = None
@@ -174,8 +178,8 @@ Default format depend on commandline arguments.
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(WebgetTool)
+    import xnet.tools.run
+    xnet.tools.run.run(WebgetTool)
 
 
 if __name__ == "__main__":
